@@ -7,7 +7,7 @@ use Error::Pure qw(err);
 use Mo qw(build is);
 use Mo::utils qw(check_array_object check_required);
 
-our $VERSION = 0.25;
+our $VERSION = 0.26;
 
 has snaks => (
 	is => 'ro',
@@ -92,16 +92,24 @@ Returns reference to array of Wikibase::Datatype::Snak instances.
  use Wikibase::Datatype::Reference;
  use Wikibase::Datatype::Snak;
  use Wikibase::Datatype::Value::String;
+ use Wikibase::Datatype::Value::Time;
 
  # Object.
  my $obj = Wikibase::Datatype::Reference->new(
          'snaks' => [
                  Wikibase::Datatype::Snak->new(
-                         'datatype' => 'string',
+                         'datatype' => 'url',
                          'datavalue' => Wikibase::Datatype::Value::String->new(
-                                 'value' => 'text',
+                                 'value' => 'https://skim.cz',
                          ),
-                         'property' => 'P11',
+                         'property' => 'P854',
+                 ),
+                 Wikibase::Datatype::Snak->new(
+                         'datatype' => 'time',
+                         'datavalue' => Wikibase::Datatype::Value::Time->new(
+                                 'value' => '+2013-12-07T00:00:00Z',
+                         ),
+                         'property' => 'P813',
                  ),
          ],
  );
@@ -113,7 +121,7 @@ Returns reference to array of Wikibase::Datatype::Snak instances.
  print "Number of snaks: ".@{$snaks_ar}."\n";
 
  # Output:
- # Number of snaks: 1
+ # Number of snaks: 2
 
 =head1 DEPENDENCIES
 
@@ -153,6 +161,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.25
+0.26
 
 =cut
